@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,14 +21,16 @@
 #ifndef BABY_H
 #define BABY_H
 
+#include "black.h"
+
 class Baby : public Black {
  public:
-  Baby(double x,double y);
+  Baby(Real x, Real y);
   ~Baby();
   void die(int how);
 
-  Boolean crash(Real speed,Ball *);  // When we crash into another ball. Returns if we are still alive
+  Boolean crash(Real speed,
+                Ball *);  // When we crash into another ball. Returns if we are still alive
 };
 
-
 #endif
