@@ -21,6 +21,7 @@
 
 #include "ball.h"
 
+#include "animatedCollection.h"
 #include "debris.h"
 #include "forcefield.h"
 #include "game.h"
@@ -36,25 +37,20 @@
 #include <math.h>
 #include <set>
 
-class std::set<Ball *> *Ball::balls;
 GLfloat Ball::dizzyTexCoords[4] = {0.f, 0.f, 1.f, 1.f};
 extern GLuint hiresSphere;
 
 void Ball::init() {
-  balls = new std::set<Ball *>();
   loadTexture("dizzy.png");
   dizzyTexCoords[0] = 0.f;
   dizzyTexCoords[1] = 0.f;
   dizzyTexCoords[2] = 1.f;
   dizzyTexCoords[3] = 1.f;
 }
-void Ball::reset() {
-  delete balls;
-  balls = new std::set<Ball *>();
-}
+
 void Ball::onRemove() {
   Animated::onRemove();
-  balls->erase(this);
+  Game::current->balls->remove(this);
 }
 
 Ball::Ball() : Animated() {
@@ -76,7 +72,7 @@ Ball::Ball() : Animated() {
   gravity = 8.0;
   bounceFactor = 0.8;
   crashTolerance = 7;
-  balls->insert(this);
+  Game::current->balls->insert(this);
   no_physics = 0;
   inPipe = 0;
 
@@ -106,7 +102,10 @@ int Ball::generateBuffers(GLuint *&idxbufs, GLuint *&databufs) {
   allocateBuffers(N, idxbufs, databufs);
 
   GLfloat color[4] = {
-      primaryColor[0], primaryColor[1], primaryColor[2], 1.,
+      primaryColor[0],
+      primaryColor[1],
+      primaryColor[2],
+      1.,
   };
   GLfloat loc[3] = {(GLfloat)position[0], (GLfloat)position[1], (GLfloat)(position[2] - sink)};
   if (modTimeLeft[MOD_GLASS]) {
@@ -1105,13 +1104,14 @@ void Ball::generateDebris(GLfloat color[4]) {
 }
 
 void Ball::handleBallCollisions() {
-  std::set<Ball *>::iterator iter = balls->begin();
-  std::set<Ball *>::iterator end = balls->end();
+  const std::set<Animated *> &balls = Game::current->balls->bboxOverlapsWith(this);
+  std::set<Animated *>::iterator iter = balls.begin();
+  std::set<Animated *>::iterator end = balls.end();
   Coord3d v;
   double dist, err, speed;
   Ball *ball;
   for (; iter != end; iter++) {
-    ball = *iter;
+    ball = (Ball *)*iter;
     if (ball == this) continue;
     if (!ball->alive) continue;
     if (ball->no_physics) continue;
@@ -1355,11 +1355,10 @@ void Ball::handlePipes(Real time) {
     normalize(dirNorm);
     Coord3d v0;  // pipe enterance -> ball position
     sub(position, pipe->from, v0);
-    double l =
-        std::max(0.0, std::min(1.0,
-                               dotProduct(v0, dirNorm) /
-                                   length(direction)));  // where along pipe ball is projected
-    Coord3d proj;  // where (as pos) the ball is projected
+    double l = std::max(
+        0.0, std::min(1.0, dotProduct(v0, dirNorm) /
+                               length(direction)));  // where along pipe ball is projected
+    Coord3d proj;                                    // where (as pos) the ball is projected
     for (int i = 0; i < 3; i++) proj[i] = pipe->from[i] + l * direction[i];
     Coord3d v1;  // projection point -> ball position
     sub(position, proj, v1);
