@@ -3,18 +3,18 @@
 */
 /*
    Copyright (C) 2000  Mathias Broxvall
-   		       Yannick Perret
+                       Yannick Perret
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -22,27 +22,29 @@
 
 #ifndef BIRD_H
 #define BIRD_H
-#ifndef ANIMATED_H
-#include "animated.h"
-#endif
 
-#define BIRD_CONSTANT_HEIGHT  1
+#include "animated.h"
+
+#define BIRD_CONSTANT_HEIGHT 1
 
 class Bird : public Animated {
-public:
-  Bird(int x,int y,int dx,int dy,Real size,Real speed);
-  void draw2();
+ public:
+  Bird(Real x, Real y, Real dx, Real dy, Real size, Real speed);
+
+  virtual int generateBuffers(GLuint*& idxbufs, GLuint*& databufs);
+  virtual void drawBuffers1(GLuint* idxbufs, GLuint* databufs);
+  virtual void drawBuffers2(GLuint* idxbufs, GLuint* databufs);
+
   void tick(Real t);
 
  protected:
-  int x,y;
-  int dx,dy;
+  Real x, y;
+  Real dx, dy;
   Real size;
   Real speed;
   Real lng;
-  float hide,animation;
+  float hide, animation;
   float rotation;
 };
 
-
 #endif
