@@ -8,12 +8,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -22,22 +22,18 @@
 #ifndef BLACK_H
 #define BLACK_H
 
-#ifndef BALL_H
 #include "ball.h"
-#endif
 
 class Black : public Ball {
  public:
-  Black(double x,double y);
+  Black(Real x, Real y);
   ~Black();
   void die(int);
   void tick(Real);
   void draw();
 
-  Real acceleration,horizon;
+  Real acceleration, horizon;
   int likesPlayer; /* 1: attracted by ply. 0: unaffected. -1: repelled */
 };
 
-
-
 #endif
