@@ -20,6 +20,8 @@
 */
 
 #include "cyclicPlatform.h"
+
+#include "animatedCollection.h"
 #include "ball.h"
 #include "game.h"
 #include "map.h"
@@ -67,10 +69,11 @@ void CyclicPlatform::tick(Real dt) {
   map->markCellsUpdated(x1, y1, x2, y2, 1);
 
   if (h < oldHeight) {
-    std::set<Ball *>::iterator iter = Ball::balls->begin();
-    std::set<Ball *>::iterator end = Ball::balls->end();
+    const std::set<Animated *> &balls = Game::current->balls->asSet();
+    std::set<Animated *>::iterator iter = balls.begin();
+    std::set<Animated *>::iterator end = balls.end();
     for (; iter != end; iter++) {
-      Ball *ball = *iter;
+      Ball *ball = (Ball *)*iter;
       if (ball->position[0] >= x1 && ball->position[0] < x2 + 1.0 && ball->position[1] >= y1 &&
           ball->position[1] < y2 + 1.0 &&
           ball->position[2] - ball->radius <=
