@@ -7,35 +7,36 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef DIAMON_H
-#define DIAMON_H
-#ifndef ANIMATED_H
+#ifndef DIAMOND_H
+#define DIAMOND_H
+
 #include "animated.h"
-#endif
 
 class Diamond : public Animated {
-public:
+ public:
   Diamond(Coord3d position);
-  void draw();
-  void draw2();
+
+  virtual int generateBuffers(GLuint*& idxbufs, GLuint*& databufs);
+  virtual void drawBuffers1(GLuint* idxbufs, GLuint* databufs);
+  virtual void drawBuffers2(GLuint* idxbufs, GLuint* databufs);
+
   void tick(Real t);
   virtual void onGet();
-  
+
  protected:
-  Real radius,fade;
-  int taken;  
+  Real fade;
+  int taken;
 };
 
-
 #endif
