@@ -19,11 +19,13 @@
 */
 
 #include "enterHighScoreMode.h"
+
 #include "font.h"
 #include "game.h"
 #include "gamer.h"
 #include "highScore.h"
 #include "menuMode.h"
+#include "menusystem.h"
 #include "player.h"
 
 #include <SDL2/SDL_keyboard.h>
@@ -39,7 +41,7 @@ void EnterHighScoreMode::init() {
   if (low_memory)
     background = NULL;
   else {
-    background = loadImage("enterHighscoreBackground.jpg");
+    background = loadImage("setupBackground.jpg");
   }
 }
 EnterHighScoreMode::EnterHighScoreMode() { memset(name, 0, sizeof(name)); }
@@ -50,15 +52,19 @@ void EnterHighScoreMode::display() {
   draw2DRectangle(0, 0, screenWidth, screenHeight, texMinX, texMinY, texMaxX, texMaxY, 1., 1.,
                   1., 1., texture);
 
+  int headerSize = computeHeaderSize();
+  int fontSize = computeMenuSize();
+
+  clearSelectionAreas();
+  addText_Center(0, headerSize, screenHeight / 2 - 2 * headerSize, _("High Score"),
+                 screenWidth / 2);
+
   char str[256];
   snprintf(str, sizeof(str), _("You got %d points"), Game::current->player1->score);
-  int size = 20;
-  Font::drawCenterSimpleText(str, screenWidth / 2, screenHeight / 2 + 1.3 * size, size, 0.85,
-                             0.85, 0.25, 1.0);
+  addText_Center(0, fontSize, screenHeight / 2, str, screenWidth / 2);
 
   snprintf(str, sizeof(str), _("Enter your name: %s"), name);
-  Font::drawCenterSimpleText(str, screenWidth / 2, screenHeight / 2 - 1.3 * size, size, 0.85,
-                             0.85, 0.25, 1.0);
+  addText_Center(0, fontSize, screenHeight / 2 + 2 * fontSize, str, screenWidth / 2);
 
   displayFrameRate();
   Leave2DMode();
