@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,6 +21,9 @@
 #ifndef ENTERHIGHSCOREMODE_H
 #define ENTERHIGHSCOREMODE_H
 
+#include "gameMode.h"
+#include "glHelp.h"
+
 class EnterHighScoreMode : public GameMode {
  public:
   EnterHighScoreMode();
@@ -31,14 +34,13 @@ class EnterHighScoreMode : public GameMode {
 
   static void init();
   static EnterHighScoreMode *enterHighScoreMode;
+
  private:
-  char name[20];  
+  char name[20];
   static SDL_Surface *background;
   GLuint texture;
   GLfloat texMinX, texMinY;
   GLfloat texMaxX, texMaxY;
-
 };
 
-
 #endif
