@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -20,21 +20,23 @@
 
 #ifndef FLAG_H
 #define FLAG_H
-#ifndef ANIMATED_H
+
 #include "animated.h"
-#endif
 
 class Flag : public Animated {
-public:
-  Flag(int x,int y,int points,int visible,Real radius);
-  void draw();
+ public:
+  Flag(Real x, Real y, int points, int visible, Real radius);
+
+  virtual int generateBuffers(GLuint*& idxbufs, GLuint*& databufs);
+  virtual void drawBuffers1(GLuint* idxbufs, GLuint* databufs);
+  virtual void drawBuffers2(GLuint* idxbufs, GLuint* databufs);
+
   void tick(Real t);
   virtual void onGet();
 
  protected:
-  int visible,x,y;
+  int visible;
   Real radius;
 };
 
-
 #endif
