@@ -33,6 +33,7 @@
 #include "general.h"
 #include "glHelp.h"
 
+class AnimatedCollection;
 class Map;
 class Player;
 class Weather;
@@ -40,7 +41,7 @@ class EditMode;
 
 class Game {
  public:
-  Game(char *, class Gamer *gamer);
+  Game(const char *, class Gamer *gamer);
   explicit Game(Map *editmap);
   virtual ~Game();
 
@@ -52,7 +53,7 @@ class Game {
   void add(class GameHook *);
   void remove(class Animated *);
   void remove(class GameHook *);
-  void loadLevel(char *level);
+  void loadLevel(const char *level);
   void clearLevel();
 
   GLfloat fogColor[4];
@@ -68,6 +69,7 @@ class Game {
   Weather *weather;
 
   static Game *current;
+  AnimatedCollection *balls;
 
   char levelName[256];
   char nextLevel[256];
