@@ -48,12 +48,16 @@ GLuint theVao = 0;
 
 TTF_Font *ingameFont;
 extern struct timespec displayStartTime;
+extern struct timespec lastDisplayStartTime;
 
 const GLfloat menuColorSelected[4] = {0.86f, 0.86f, 0.86f, 1.f};
 const GLfloat menuColor[4] = {0.86f, 0.86f, 0.25f, 1.f};
 
 double fake_rand[4711];
-double frand(int i) { return fake_rand[i % 4711]; }
+double frand(size_t i) {
+  /* size_t is nonnegative so no inputs will crash */
+  return fake_rand[i % 4711];
+}
 double frand() { return (rand() % (1 << 30)) / ((double)(1 << 30)); }
 
 #define GLHELP_MAX_TEXTURES 256
@@ -124,7 +128,7 @@ static SDL_Surface *drawStringToSurface(struct StringInfo &inf, int outlined) {
 }
 
 int draw2DString(TTF_Font *font, const char *string, int x, int y, float red, float green,
-                 float blue, float alpha, int outlined, int align) {
+                 float blue, float alpha, int outlined, int align, int maxwidth) {
   struct StringInfo inf;
   inf.color.r = 255 * red;
   inf.color.g = 255 * green;
@@ -149,12 +153,11 @@ int draw2DString(TTF_Font *font, const char *string, int x, int y, float red, fl
   struct StringCache &cached = strcache[inf];
   cached.tick = stringTick;
 
-  y -= cached.h / 2;
-
-  draw2DRectangle(x - align * cached.w / 2, y, cached.w, cached.h, cached.texcoord[0],
-                  cached.texcoord[1], cached.texcoord[2], cached.texcoord[3], 1., 1., 1., 1.,
-                  cached.texture);
-  return cached.w;
+  GLfloat shrink = (maxwidth > 0 && maxwidth < cached.w) ? (maxwidth / (GLfloat)cached.w) : 1.;
+  draw2DRectangle(x - shrink * align * cached.w / 2, y - shrink * cached.h / 2,
+                  shrink * cached.w, shrink * cached.h, cached.texcoord[0], cached.texcoord[1],
+                  cached.texcoord[2], cached.texcoord[3], 1., 1., 1., 1., cached.texture);
+  return maxwidth > 0 ? std::min(cached.w, maxwidth) : cached.w;
 }
 
 void update2DStringCache() {
@@ -920,10 +923,10 @@ void message(char *A, char *B) {
   Enter2DMode();
   draw2DRectangle(x1, y1, x2 - x1, y2 - y1, 0., 0., 1., 1., 0.2, 0.5, 0.2, 0.5);
 
-  Font::drawCenterSimpleText(A, screenWidth / 2 + size, screenHeight / 2 - size, size, 0.5,
-                             1.0, 0.2, 1.0);
-  Font::drawCenterSimpleText(B, screenWidth / 2 + size, screenHeight / 2 + 14, size, 0.5, 1.0,
-                             0.2, 1.0);
+  Font::drawCenterSimpleText(A, screenWidth / 2, screenHeight / 2 - size, size, 0.5, 1.0, 0.2,
+                             1.0);
+  Font::drawCenterSimpleText(B, screenWidth / 2, screenHeight / 2 + 14, size, 0.5, 1.0, 0.2,
+                             1.0);
 
   Leave2DMode();
 }
@@ -947,12 +950,12 @@ void multiMessage(int nlines, const char *left[], const char *right[]) {
   for (int i = 0; i < nlines; i++) {
     h_now += 2 * size;
     if (left[i]) {
-      Font::drawSimpleText(left[i], screenWidth / 2 - width / 2 + size,
+      Font::drawSimpleText(left[i], screenWidth / 2 - width / 2,
                            screenHeight / 2 - total_height / 2 + h_now, size, 0.5, 1.0, 0.2,
                            1.0);
     }
     if (right[i]) {
-      Font::drawRightSimpleText(right[i], screenWidth / 2 + width / 2 + size,
+      Font::drawRightSimpleText(right[i], screenWidth / 2 + width / 2,
                                 screenHeight / 2 - total_height / 2 + h_now, size, 0.5, 1.0,
                                 0.2, 1.0);
     }
@@ -1242,8 +1245,8 @@ int resetTextures() {
 
 /* Calculates and displays current framerate */
 void displayFrameRate() {
-  /* We don't include the time spent on Flip(), but everything else we do*/
-  double td = getTimeDifference(displayStartTime, getMonotonicTime());
+  /* Frame rate is given for the previous period. */
+  double td = getTimeDifference(lastDisplayStartTime, displayStartTime);
   if (td > 1.0)
     fps = 1.0;
   else if (td <= 1e-4) {
