@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,6 +21,9 @@
 #ifndef HOF_H
 #define HOF_H
 
+#include "gameMode.h"
+#include "glHelp.h"
+
 class HallOfFameMode : public GameMode {
  public:
   HallOfFameMode();
@@ -29,19 +32,19 @@ class HallOfFameMode : public GameMode {
   void deactivated();
   void key(int);
   void idle(Real);
-  void mouseDown(int state,int x,int y);
+  void mouseDown(int state, int x, int y);
 
   static void init();
   static HallOfFameMode *hallOfFameMode;
   int levelSet;
+
  private:
   double timeLeft;
   int isExiting;
   static SDL_Surface *background;
 
   GLuint texture;
-  GLfloat texMinX, texMinY;
-  GLfloat texMaxX, texMaxY;
+  GLfloat texCoord[4];
 };
 
 #endif
