@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,9 +21,8 @@
 #ifndef MAINMODE_H
 #define MAINMODE_H
 
-#ifndef GAMEMODE_H
 #include "gameMode.h"
-#endif
+#include "glHelp.h"
 
 class MainMode : public GameMode {
  public:
@@ -32,16 +31,16 @@ class MainMode : public GameMode {
 
   void display();
   void key(int);
-  void special(int,int,int);
+  void special(int, int, int);
   void idle(Real td);
   void doExpensiveComputations();
-  void mouse(int state,int x,int y);
-  void mouseDown(int button,int x,int y);
+  void mouse(int state, int x, int y);
+  void mouseDown(int button, int x, int y);
 
   void activated();
   void deactivated();
 
-  void playerLoose();
+  void playerLose();
   void playerDie();
   void startGame();
   void restartPlayer();
@@ -50,31 +49,31 @@ class MainMode : public GameMode {
   void levelComplete();
   void bonusLevelComplete();
 
-  void renderEnvironmentTexture(GLuint texture,Coord3d focus);
-  void convertToFisheye(char *convertedData,char *originalData,int originalSize);
+  void setupLighting() const;
+  void renderEnvironmentTexture(GLuint texture, Coord3d focus) const;
   Real flash;
 
   static void init();
   static MainMode *mainMode;
 
-  double zAngle, wantedZAngle, xyAngle, wantedXYAngle;  
+  double zAngle, wantedZAngle, xyAngle, wantedXYAngle;
   Coord3d camFocus, camDelta;
+  Matrix4d cameraModelView;
+  Matrix4d cameraProjection;
+
  protected:
  private:
   int gameStatus;
   double statusCount;
   double time;
   double pause_time;
-  int go_to_pause;  
+  int go_to_pause;
 
-  static const int statusBeforeGame,statusGameOver,statusInGame;
-  static const int statusRestartPlayer,statusNextLevel,statusVictory;
-  static const int statusLevelComplete,statusBonusLevelComplete;
+  static const int statusBeforeGame, statusGameOver, statusInGame;
+  static const int statusRestartPlayer, statusNextLevel, statusVictory;
+  static const int statusLevelComplete, statusBonusLevelComplete;
   static const int statusPaused;
 
-  //static SDL_Surface *panel,*life,*nolife;
-  static char *environmentTextureData, *viewportData;
-
   char *mapname;
 };
 
