@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,31 +21,30 @@
 #ifndef PLAYER_H
 #define PLAYER_H
 
-#ifndef BALL_H
 #include "ball.h"
-#endif
 
 class Player : public Ball {
  public:
-  Player(class Gamer *gamer);
+  Player();
   virtual ~Player();
-  
+
   void draw();
   void tick(Real time);
   void key(int k);
   void die(int);
   void newLevel();
-  void setStartVariables();        /**< Setup all default variables when starting a level */
-  void restart(Coord3d);      /**< Restart the ball at given position */
-  void mouse(int state,int x,int y);
+  void setStartVariables(); /**< Setup all default variables when starting a level */
+  void restart(Coord3d);    /**< Restart the ball at given position */
+  void mouse(int state, int x, int y);
   void setHealth(Real);
   virtual Boolean crash(Real speed);
 
   double health;
   double oxygen;
   double moveBurst;
-  int lives,timeLeft,score,hasWon;
+  int lives, timeLeft, score, hasWon;
   Boolean playing;
+
  private:
   void jump();
 
