@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -21,6 +21,9 @@
 #ifndef SETUPMODE_H
 #define SETUPMODE_H
 
+#include "gameMode.h"
+#include "glHelp.h"
+
 class SetupMode : public GameMode {
  public:
   SetupMode();
@@ -29,25 +32,26 @@ class SetupMode : public GameMode {
   void deactivated();
   void key(int);
   void idle(Real td);
-  void mouseDown(int state,int x,int y);
+  void mouseDown(int state, int x, int y);
 
   static void init();
   static SetupMode *setupMode;
+
  private:
   void start();
   void levelSetChanged();
 
   class Gamer *gamer;
-  int levelSet,level,name;
+  int levelSet, level, name;
   static SDL_Surface *background;
   double t;
 
   GLuint texture;
-  GLfloat texMinX, texMinY;
-  GLfloat texMaxX, texMaxY;
+  GLfloat texCoord[4];
 
   GLuint screenshot;
-  GLfloat screenshotMax[2];
+  GLfloat scrshtCoord[4];
+  GLuint scrshtW, scrshtH;
 };
 
 #endif
